@@ -1,25 +1,28 @@
-// +build linux
+// SPDX-License-Identifier: BSD-3-Clause
+//go:build linux
 
 package disk
 
 import (
 	"bufio"
-	"bytes"
 	"context"
+	"errors"
 	"fmt"
-	"io/ioutil"
+	"os"
+	"path"
 	"path/filepath"
 	"strconv"
 	"strings"
 
 	"golang.org/x/sys/unix"
 
-	"github.com/shirou/gopsutil/internal/common"
+	"github.com/shirou/gopsutil/v4/internal/common"
 )
 
 const (
-	SectorSize = 512
+	sectorSize = 512
 )
+
 const (
 	// man statfs
 	ADFS_SUPER_MAGIC      = 0xadf5
@@ -47,6 +50,7 @@ const (
 	FUSE_SUPER_MAGIC      = 0x65735546
 	FUTEXFS_SUPER_MAGIC   = 0xBAD1DEA
 	HFS_SUPER_MAGIC       = 0x4244
+	HFSPLUS_SUPER_MAGIC   = 0x482b
 	HOSTFS_SUPER_MAGIC    = 0x00c0ffee
 	HPFS_SUPER_MAGIC      = 0xF995E849
 	HUGETLBFS_MAGIC       = 0x958458f6
@@ -96,8 +100,12 @@ const (
 	AFS_SUPER_MAGIC             = 0x5346414F
 	AUFS_SUPER_MAGIC            = 0x61756673
 	ANON_INODE_FS_SUPER_MAGIC   = 0x09041934
+	BPF_FS_MAGIC                = 0xCAFE4A11
 	CEPH_SUPER_MAGIC            = 0x00C36400
+	CGROUP2_SUPER_MAGIC         = 0x63677270
+	CONFIGFS_MAGIC              = 0x62656570
 	ECRYPTFS_SUPER_MAGIC        = 0xF15F
+	F2FS_SUPER_MAGIC            = 0xF2F52010
 	FAT_SUPER_MAGIC             = 0x4006
 	FHGFS_SUPER_MAGIC           = 0x19830326
 	FUSEBLK_SUPER_MAGIC         = 0x65735546
@@ -112,9 +120,11 @@ const (
 	KAFS_SUPER_MAGIC            = 0x6B414653
 	LUSTRE_SUPER_MAGIC          = 0x0BD00BD0
 	NFSD_SUPER_MAGIC            = 0x6E667364
+	NSFS_MAGIC                  = 0x6E736673
 	PANFS_SUPER_MAGIC           = 0xAAD7AAEA
 	RPC_PIPEFS_SUPER_MAGIC      = 0x67596969
 	SECURITYFS_SUPER_MAGIC      = 0x73636673
+	TRACEFS_MAGIC               = 0x74726163
 	UFS_BYTESWAPPED_SUPER_MAGIC = 0x54190100
 	VMHGFS_SUPER_MAGIC          = 0xBACBACBC
 	VZFS_SUPER_MAGIC            = 0x565A4653
@@ -133,21 +143,26 @@ var fsTypeMap = map[int64]string{
 	BDEVFS_MAGIC:                "bdevfs",              /* 0x62646576 local */
 	BFS_MAGIC:                   "bfs",                 /* 0x1BADFACE local */
 	BINFMTFS_MAGIC:              "binfmt_misc",         /* 0x42494E4D local */
+	BPF_FS_MAGIC:                "bpf",                 /* 0xCAFE4A11 local */
 	BTRFS_SUPER_MAGIC:           "btrfs",               /* 0x9123683E local */
 	CEPH_SUPER_MAGIC:            "ceph",                /* 0x00C36400 remote */
 	CGROUP_SUPER_MAGIC:          "cgroupfs",            /* 0x0027E0EB local */
+	CGROUP2_SUPER_MAGIC:         "cgroup2fs",           /* 0x63677270 local */
 	CIFS_MAGIC_NUMBER:           "cifs",                /* 0xFF534D42 remote */
 	CODA_SUPER_MAGIC:            "coda",                /* 0x73757245 remote */
 	COH_SUPER_MAGIC:             "coh",                 /* 0x012FF7B7 local */
+	CONFIGFS_MAGIC:              "configfs",            /* 0x62656570 local */
 	CRAMFS_MAGIC:                "cramfs",              /* 0x28CD3D45 local */
 	DEBUGFS_MAGIC:               "debugfs",             /* 0x64626720 local */
 	DEVFS_SUPER_MAGIC:           "devfs",               /* 0x1373 local */
 	DEVPTS_SUPER_MAGIC:          "devpts",              /* 0x1CD1 local */
 	ECRYPTFS_SUPER_MAGIC:        "ecryptfs",            /* 0xF15F local */
+	EFIVARFS_MAGIC:              "efivarfs",            /* 0xDE5E81E4 local */
 	EFS_SUPER_MAGIC:             "efs",                 /* 0x00414A53 local */
 	EXT_SUPER_MAGIC:             "ext",                 /* 0x137D local */
 	EXT2_SUPER_MAGIC:            "ext2/ext3",           /* 0xEF53 local */
 	EXT2_OLD_SUPER_MAGIC:        "ext2",                /* 0xEF51 local */
+	F2FS_SUPER_MAGIC:            "f2fs",                /* 0xF2F52010 local */
 	FAT_SUPER_MAGIC:             "fat",                 /* 0x4006 local */
 	FHGFS_SUPER_MAGIC:           "fhgfs",               /* 0x19830326 remote */
 	FUSEBLK_SUPER_MAGIC:         "fuseblk",             /* 0x65735546 remote */
@@ -156,6 +171,7 @@ var fsTypeMap = map[int64]string{
 	GFS_SUPER_MAGIC:             "gfs/gfs2",            /* 0x1161970 remote */
 	GPFS_SUPER_MAGIC:            "gpfs",                /* 0x47504653 remote */
 	HFS_SUPER_MAGIC:             "hfs",                 /* 0x4244 local */
+	HFSPLUS_SUPER_MAGIC:         "hfsplus",             /* 0x482b local */
 	HPFS_SUPER_MAGIC:            "hpfs",                /* 0xF995E849 local */
 	HUGETLBFS_MAGIC:             "hugetlbfs",           /* 0x958458F6 local */
 	MTD_INODE_FS_SUPER_MAGIC:    "inodefs",             /* 0x11307854 local */
@@ -179,6 +195,7 @@ var fsTypeMap = map[int64]string{
 	NFS_SUPER_MAGIC:             "nfs",                 /* 0x6969 remote */
 	NFSD_SUPER_MAGIC:            "nfsd",                /* 0x6E667364 remote */
 	NILFS_SUPER_MAGIC:           "nilfs",               /* 0x3434 local */
+	NSFS_MAGIC:                  "nsfs",                /* 0x6E736673 local */
 	NTFS_SB_MAGIC:               "ntfs",                /* 0x5346544E local */
 	OPENPROM_SUPER_MAGIC:        "openprom",            /* 0x9FA1 local */
 	OCFS2_SUPER_MAGIC:           "ocfs2",               /* 0x7461636f remote */
@@ -201,6 +218,7 @@ var fsTypeMap = map[int64]string{
 	SYSV2_SUPER_MAGIC:           "sysv2",               /* 0x012FF7B6 local */
 	SYSV4_SUPER_MAGIC:           "sysv4",               /* 0x012FF7B5 local */
 	TMPFS_MAGIC:                 "tmpfs",               /* 0x01021994 local */
+	TRACEFS_MAGIC:               "tracefs",             /* 0x74726163 local */
 	UDF_SUPER_MAGIC:             "udf",                 /* 0x15013346 local */
 	UFS_MAGIC:                   "ufs",                 /* 0x00011954 local */
 	UFS_BYTESWAPPED_SUPER_MAGIC: "ufs",                 /* 0x54190100 local */
@@ -216,38 +234,125 @@ var fsTypeMap = map[int64]string{
 	ZFS_SUPER_MAGIC:             "zfs",                 /* 0x2FC12FC1 local */
 }
 
-// Partitions returns disk partitions. If all is false, returns
-// physical devices only (e.g. hard disks, cd-rom drives, USB keys)
-// and ignore all others (e.g. memory partitions such as /dev/shm)
-func Partitions(all bool) ([]PartitionStat, error) {
-	return PartitionsWithContext(context.Background(), all)
+// readMountFile reads mountinfo or mounts file under the specified root path
+// (eg, /proc/1, /proc/self, etc)
+func readMountFile(root string) (lines []string, useMounts bool, filename string, err error) {
+	filename = path.Join(root, "mountinfo")
+	lines, err = common.ReadLines(filename)
+	if err != nil {
+		var pathErr *os.PathError
+		if !errors.As(err, &pathErr) {
+			return
+		}
+		// if kernel does not support 1/mountinfo, fallback to 1/mounts (<2.6.26)
+		useMounts = true
+		filename = path.Join(root, "mounts")
+		lines, err = common.ReadLines(filename)
+		if err != nil {
+			return
+		}
+		return
+	}
+	return
 }
 
 func PartitionsWithContext(ctx context.Context, all bool) ([]PartitionStat, error) {
-	filename := common.HostProc("self/mounts")
-	lines, err := common.ReadLines(filename)
-	if err != nil {
-		return nil, err
+	// by default, try "/proc/1/..." first
+	root := common.HostProcWithContext(ctx, path.Join("1"))
+
+	// force preference for dirname of HOST_PROC_MOUNTINFO, if set  #1271
+	hpmPath := common.HostProcMountInfoWithContext(ctx)
+	if hpmPath != "" {
+		root = filepath.Dir(hpmPath)
 	}
 
-	fs, err := getFileSystems()
+	lines, useMounts, filename, err := readMountFile(root)
 	if err != nil {
+		if hpmPath != "" { // don't fallback with HOST_PROC_MOUNTINFO
+			return nil, err
+		}
+		// fallback to "/proc/self/..."  #1159
+		lines, useMounts, filename, err = readMountFile(common.HostProcWithContext(ctx, path.Join("self")))
+		if err != nil {
+			return nil, err
+		}
+	}
+
+	fs, err := getFileSystems(ctx)
+	if err != nil && !all {
 		return nil, err
 	}
 
 	ret := make([]PartitionStat, 0, len(lines))
 
 	for _, line := range lines {
-		fields := strings.Fields(line)
-		d := PartitionStat{
-			Device:     fields[0],
-			Mountpoint: fields[1],
-			Fstype:     fields[2],
-			Opts:       fields[3],
-		}
-		if all == false {
-			if d.Device == "none" || !common.StringsHas(fs, d.Fstype) {
-				continue
+		var d PartitionStat
+		if useMounts {
+			fields := strings.Fields(line)
+
+			d = PartitionStat{
+				Device:     fields[0],
+				Mountpoint: unescapeFstab(fields[1]),
+				Fstype:     fields[2],
+				Opts:       strings.Fields(fields[3]),
+			}
+
+			if !all {
+				if d.Device == "none" || !common.StringsHas(fs, d.Fstype) {
+					continue
+				}
+			}
+		} else {
+			// a line of 1/mountinfo has the following structure:
+			// 36  35  98:0 /mnt1 /mnt2 rw,noatime master:1 - ext3 /dev/root rw,errors=continue
+			// (1) (2) (3)   (4)   (5)      (6)      (7)   (8) (9)   (10)         (11)
+
+			// split the mountinfo line by the separator hyphen
+			parts := strings.Split(line, " - ")
+			if len(parts) != 2 {
+				return nil, fmt.Errorf("found invalid mountinfo line in file %s: %s ", filename, line)
+			}
+
+			fields := strings.Fields(parts[0])
+			blockDeviceID := fields[2]
+			mountPoint := fields[4]
+			mountOpts := strings.Split(fields[5], ",")
+
+			if rootDir := fields[3]; rootDir != "" && rootDir != "/" {
+				mountOpts = append(mountOpts, "bind")
+			}
+
+			fields = strings.Fields(parts[1])
+			fstype := fields[0]
+			device := fields[1]
+
+			d = PartitionStat{
+				Device:     device,
+				Mountpoint: unescapeFstab(mountPoint),
+				Fstype:     fstype,
+				Opts:       mountOpts,
+			}
+
+			if !all {
+				if d.Device == "none" || !common.StringsHas(fs, d.Fstype) {
+					continue
+				}
+			}
+
+			if strings.HasPrefix(d.Device, "/dev/mapper/") {
+				devpath, err := filepath.EvalSymlinks(common.HostDevWithContext(ctx, strings.Replace(d.Device, "/dev", "", 1)))
+				if err == nil {
+					d.Device = devpath
+				}
+			}
+
+			// /dev/root is not the real device name
+			// so we get the real device name from its major/minor number
+			if d.Device == "/dev/root" {
+				devpath, err := os.Readlink(common.HostSysWithContext(ctx, "/dev/block/"+blockDeviceID))
+				if err == nil {
+					d.Device = strings.Replace(d.Device, "root", filepath.Base(devpath), 1)
+				}
 			}
 		}
 		ret = append(ret, d)
@@ -257,8 +362,8 @@ func PartitionsWithContext(ctx context.Context, all bool) ([]PartitionStat, erro
 }
 
 // getFileSystems returns supported filesystems from /proc/filesystems
-func getFileSystems() ([]string, error) {
-	filename := common.HostProc("filesystems")
+func getFileSystems(ctx context.Context) ([]string, error) {
+	filename := common.HostProcWithContext(ctx, "filesystems")
 	lines, err := common.ReadLines(filename)
 	if err != nil {
 		return nil, err
@@ -279,17 +384,13 @@ func getFileSystems() ([]string, error) {
 	return ret, nil
 }
 
-func IOCounters(names ...string) (map[string]IOCountersStat, error) {
-	return IOCountersWithContext(context.Background(), names...)
-}
-
 func IOCountersWithContext(ctx context.Context, names ...string) (map[string]IOCountersStat, error) {
-	filename := common.HostProc("diskstats")
+	filename := common.HostProcWithContext(ctx, "diskstats")
 	lines, err := common.ReadLines(filename)
 	if err != nil {
 		return nil, err
 	}
-	ret := make(map[string]IOCountersStat, 0)
+	ret := make(map[string]IOCountersStat)
 	empty := IOCountersStat{}
 
 	// use only basename such as "/dev/sda1" to "sda1"
@@ -354,8 +455,8 @@ func IOCountersWithContext(ctx context.Context, names ...string) (map[string]IOC
 			return ret, err
 		}
 		d := IOCountersStat{
-			ReadBytes:        rbytes * SectorSize,
-			WriteBytes:       wbytes * SectorSize,
+			ReadBytes:        rbytes * sectorSize,
+			WriteBytes:       wbytes * sectorSize,
 			ReadCount:        reads,
 			WriteCount:       writes,
 			MergedReadCount:  mergedReads,
@@ -371,70 +472,83 @@ func IOCountersWithContext(ctx context.Context, names ...string) (map[string]IOC
 		}
 		d.Name = name
 
-		d.SerialNumber = GetDiskSerialNumber(name)
-		d.Label = GetLabel(name)
+		// Names passed in can be full paths (/dev/sda) or just device names (sda).
+		// Since `name` here is already a basename, re-add the /dev path.
+		// This is not ideal, but we may break the API by changing how SerialNumberWithContext
+		// works.
+		d.SerialNumber, _ = SerialNumberWithContext(ctx, common.HostDevWithContext(ctx, name))
+		d.Label, _ = LabelWithContext(ctx, name)
 
 		ret[name] = d
 	}
 	return ret, nil
 }
 
-// GetDiskSerialNumber returns Serial Number of given device or empty string
-// on error. Name of device is expected, eg. /dev/sda
-func GetDiskSerialNumber(name string) string {
-	return GetDiskSerialNumberWithContext(context.Background(), name)
+func udevData(ctx context.Context, major uint32, minor uint32, name string) (string, error) {
+	udevDataPath := common.HostRunWithContext(ctx, fmt.Sprintf("udev/data/b%d:%d", major, minor))
+	if f, err := os.Open(udevDataPath); err == nil {
+		defer f.Close()
+		scanner := bufio.NewScanner(f)
+		for scanner.Scan() {
+			values := strings.SplitN(scanner.Text(), "=", 3)
+			if len(values) == 2 && values[0] == name {
+				return values[1], nil
+			}
+		}
+		return "", scanner.Err()
+	} else if !os.IsNotExist(err) {
+		return "", err
+	}
+	return "", nil
 }
 
-func GetDiskSerialNumberWithContext(ctx context.Context, name string) string {
+func SerialNumberWithContext(ctx context.Context, name string) (string, error) {
 	var stat unix.Stat_t
-	err := unix.Stat(name, &stat)
-	if err != nil {
-		return ""
+	if err := unix.Stat(name, &stat); err != nil {
+		return "", err
 	}
 	major := unix.Major(uint64(stat.Rdev))
 	minor := unix.Minor(uint64(stat.Rdev))
 
-	// Try to get the serial from udev data
-	udevDataPath := fmt.Sprintf("/run/udev/data/b%d:%d", major, minor)
-	if udevdata, err := ioutil.ReadFile(udevDataPath); err == nil {
-		scanner := bufio.NewScanner(bytes.NewReader(udevdata))
-		for scanner.Scan() {
-			values := strings.Split(scanner.Text(), "=")
-			if len(values) == 2 && values[0] == "E:ID_SERIAL" {
-				return values[1]
-			}
-		}
+	sserial, _ := udevData(ctx, major, minor, "E:ID_SERIAL")
+	if sserial != "" {
+		return sserial, nil
 	}
 
 	// Try to get the serial from sysfs, look at the disk device (minor 0) directly
 	// because if it is a partition it is not going to contain any device information
-	devicePath := fmt.Sprintf("/sys/dev/block/%d:0/device", major)
-	model, _ := ioutil.ReadFile(filepath.Join(devicePath, "model"))
-	serial, _ := ioutil.ReadFile(filepath.Join(devicePath, "serial"))
+	devicePath := common.HostSysWithContext(ctx, fmt.Sprintf("dev/block/%d:0/device", major))
+	model, _ := os.ReadFile(filepath.Join(devicePath, "model"))
+	serial, _ := os.ReadFile(filepath.Join(devicePath, "serial"))
 	if len(model) > 0 && len(serial) > 0 {
-		return fmt.Sprintf("%s_%s", string(model), string(serial))
+		return fmt.Sprintf("%s_%s", string(model), string(serial)), nil
 	}
-	return ""
+	return "", nil
 }
 
-// GetLabel returns label of given device or empty string on error.
-// Name of device is expected, eg. /dev/sda
-// Supports label based on devicemapper name
-// See https://www.kernel.org/doc/Documentation/ABI/testing/sysfs-block-dm
-func GetLabel(name string) string {
+func LabelWithContext(ctx context.Context, name string) (string, error) {
 	// Try label based on devicemapper name
-	dmname_filename := common.HostSys(fmt.Sprintf("block/%s/dm/name", name))
-
-	if !common.PathExists(dmname_filename) {
-		return ""
+	dmname_filename := common.HostSysWithContext(ctx, fmt.Sprintf("block/%s/dm/name", name))
+	// Could errors.Join errs with Go >= 1.20
+	if common.PathExists(dmname_filename) {
+		dmname, err := os.ReadFile(dmname_filename)
+		if err == nil {
+			return strings.TrimSpace(string(dmname)), nil
+		}
 	}
+	// Try udev data
+	var stat unix.Stat_t
+	if err := unix.Stat(common.HostDevWithContext(ctx, name), &stat); err != nil {
+		return "", err
+	}
+	major := unix.Major(uint64(stat.Rdev))
+	minor := unix.Minor(uint64(stat.Rdev))
 
-	dmname, err := ioutil.ReadFile(dmname_filename)
+	label, err := udevData(ctx, major, minor, "E:ID_FS_LABEL")
 	if err != nil {
-		return ""
-	} else {
-		return string(dmname)
+		return "", err
 	}
+	return label, nil
 }
 
 func getFsType(stat unix.Statfs_t) string {
