@@ -1,20 +1,20 @@
-// +build windows
+// SPDX-License-Identifier: BSD-3-Clause
+//go:build windows
 
 package host
 
 import (
 	"context"
 	"fmt"
-	"os"
-	"runtime"
+	"strconv"
 	"strings"
 	"sync/atomic"
 	"syscall"
 	"time"
 	"unsafe"
 
-	"github.com/shirou/gopsutil/internal/common"
-	process "github.com/shirou/gopsutil/process"
+	"github.com/shirou/gopsutil/v4/internal/common"
+	"github.com/shirou/gopsutil/v4/process"
 	"golang.org/x/sys/windows"
 )
 
@@ -22,6 +22,7 @@ var (
 	procGetSystemTimeAsFileTime = common.Modkernel32.NewProc("GetSystemTimeAsFileTime")
 	procGetTickCount32          = common.Modkernel32.NewProc("GetTickCount")
 	procGetTickCount64          = common.Modkernel32.NewProc("GetTickCount64")
+	procGetNativeSystemInfo     = common.Modkernel32.NewProc("GetNativeSystemInfo")
 	procRtlGetVersion           = common.ModNt.NewProc("RtlGetVersion")
 )
 
@@ -40,59 +41,21 @@ type osVersionInfoExW struct {
 	wReserved           uint8
 }
 
-func Info() (*InfoStat, error) {
-	return InfoWithContext(context.Background())
+type systemInfo struct {
+	wProcessorArchitecture      uint16
+	wReserved                   uint16
+	dwPageSize                  uint32
+	lpMinimumApplicationAddress uintptr
+	lpMaximumApplicationAddress uintptr
+	dwActiveProcessorMask       uintptr
+	dwNumberOfProcessors        uint32
+	dwProcessorType             uint32
+	dwAllocationGranularity     uint32
+	wProcessorLevel             uint16
+	wProcessorRevision          uint16
 }
 
-func InfoWithContext(ctx context.Context) (*InfoStat, error) {
-	ret := &InfoStat{
-		OS: runtime.GOOS,
-	}
-
-	{
-		hostname, err := os.Hostname()
-		if err == nil {
-			ret.Hostname = hostname
-		}
-	}
-
-	{
-		platform, family, version, err := PlatformInformationWithContext(ctx)
-		if err == nil {
-			ret.Platform = platform
-			ret.PlatformFamily = family
-			ret.PlatformVersion = version
-		} else {
-			return ret, err
-		}
-	}
-
-	{
-		boot, err := BootTime()
-		if err == nil {
-			ret.BootTime = boot
-			ret.Uptime, _ = Uptime()
-		}
-	}
-
-	{
-		hostID, err := getMachineGuid()
-		if err == nil {
-			ret.HostID = strings.ToLower(hostID)
-		}
-	}
-
-	{
-		procs, err := process.Pids()
-		if err == nil {
-			ret.Procs = uint64(len(procs))
-		}
-	}
-
-	return ret, nil
-}
-
-func getMachineGuid() (string, error) {
+func HostIDWithContext(ctx context.Context) (string, error) {
 	// there has been reports of issues on 32bit using golang.org/x/sys/windows/registry, see https://github.com/shirou/gopsutil/pull/312#issuecomment-277422612
 	// for rationale of using windows.RegOpenKeyEx/RegQueryValueEx instead of registry.OpenKey/GetStringValue
 	var h windows.Handle
@@ -119,14 +82,26 @@ func getMachineGuid() (string, error) {
 		return "", fmt.Errorf("HostID incorrect: %q\n", hostID)
 	}
 
-	return hostID, nil
+	return strings.ToLower(hostID), nil
 }
 
-func Uptime() (uint64, error) {
-	return UptimeWithContext(context.Background())
+func numProcs(ctx context.Context) (uint64, error) {
+	procs, err := process.PidsWithContext(ctx)
+	if err != nil {
+		return 0, err
+	}
+	return uint64(len(procs)), nil
 }
 
 func UptimeWithContext(ctx context.Context) (uint64, error) {
+	up, err := uptimeMillis()
+	if err != nil {
+		return 0, err
+	}
+	return uint64((time.Duration(up) * time.Millisecond).Seconds()), nil
+}
+
+func uptimeMillis() (uint64, error) {
 	procGetTickCount := procGetTickCount64
 	err := procGetTickCount64.Find()
 	if err != nil {
@@ -136,39 +111,39 @@ func UptimeWithContext(ctx context.Context) (uint64, error) {
 	if lastErr != 0 {
 		return 0, lastErr
 	}
-	return uint64((time.Duration(r1) * time.Millisecond).Seconds()), nil
-}
-
-func bootTimeFromUptime(up uint64) uint64 {
-	return uint64(time.Now().Unix()) - up
+	return uint64(r1), nil
 }
 
 // cachedBootTime must be accessed via atomic.Load/StoreUint64
 var cachedBootTime uint64
 
-func BootTime() (uint64, error) {
-	return BootTimeWithContext(context.Background())
-}
-
 func BootTimeWithContext(ctx context.Context) (uint64, error) {
-	t := atomic.LoadUint64(&cachedBootTime)
-	if t != 0 {
-		return t, nil
+	if enableBootTimeCache {
+		t := atomic.LoadUint64(&cachedBootTime)
+		if t != 0 {
+			return t, nil
+		}
 	}
-	up, err := Uptime()
+	up, err := uptimeMillis()
 	if err != nil {
 		return 0, err
 	}
-	t = bootTimeFromUptime(up)
-	atomic.StoreUint64(&cachedBootTime, t)
+	t := uint64((time.Duration(timeSinceMillis(up)) * time.Millisecond).Seconds())
+	if enableBootTimeCache {
+		atomic.StoreUint64(&cachedBootTime, t)
+	}
 	return t, nil
 }
 
-func PlatformInformation() (platform string, family string, version string, err error) {
-	return PlatformInformationWithContext(context.Background())
+func PlatformInformationWithContext(ctx context.Context) (platform string, family string, version string, err error) {
+	platform, family, _, displayVersion, err := platformInformation(ctx)
+	if err != nil {
+		return "", "", "", err
+	}
+	return platform, family, displayVersion, nil
 }
 
-func PlatformInformationWithContext(ctx context.Context) (platform string, family string, version string, err error) {
+func platformInformation(ctx context.Context) (platform, family, version, displayVersion string, err error) {
 	// GetVersionEx lies on Windows 8.1 and returns as Windows 8 if we don't declare compatibility in manifest
 	// RtlGetVersion bypasses this lying layer and returns the true Windows version
 	// https://docs.microsoft.com/en-us/windows-hardware/drivers/ddi/content/wdm/nf-wdm-rtlgetversion
@@ -181,7 +156,7 @@ func PlatformInformationWithContext(ctx context.Context) (platform string, famil
 	}
 
 	// Platform
-	var h windows.Handle // like getMachineGuid(), we query the registry using the raw windows.RegOpenKeyEx/RegQueryValueEx
+	var h windows.Handle // like HostIDWithContext(), we query the registry using the raw windows.RegOpenKeyEx/RegQueryValueEx
 	err = windows.RegOpenKeyEx(windows.HKEY_LOCAL_MACHINE, windows.StringToUTF16Ptr(`SOFTWARE\Microsoft\Windows NT\CurrentVersion`), 0, windows.KEY_READ|windows.KEY_WOW64_64KEY, &h)
 	if err != nil {
 		return
@@ -199,6 +174,19 @@ func PlatformInformationWithContext(ctx context.Context) (platform string, famil
 		return
 	}
 	platform = windows.UTF16ToString(regBuf[:])
+	if strings.Contains(platform, "Windows 10") { // check build number to determine whether it's actually Windows 11
+		err = windows.RegQueryValueEx(h, windows.StringToUTF16Ptr(`CurrentBuildNumber`), nil, &valType, nil, &bufLen)
+		if err == nil {
+			regBuf = make([]uint16, bufLen/2+1)
+			err = windows.RegQueryValueEx(h, windows.StringToUTF16Ptr(`CurrentBuildNumber`), nil, &valType, (*byte)(unsafe.Pointer(&regBuf[0])), &bufLen)
+			if err == nil {
+				buildNumberStr := windows.UTF16ToString(regBuf[:])
+				if buildNumber, err := strconv.ParseInt(buildNumberStr, 10, 32); err == nil && buildNumber >= 22000 {
+					platform = strings.Replace(platform, "Windows 10", "Windows 11", 1)
+				}
+			}
+		}
+	}
 	if !strings.HasPrefix(platform, "Microsoft") {
 		platform = "Microsoft " + platform
 	}
@@ -211,6 +199,22 @@ func PlatformInformationWithContext(ctx context.Context) (platform string, famil
 		}
 	}
 
+	var UBR uint32 // Update Build Revision
+	err = windows.RegQueryValueEx(h, windows.StringToUTF16Ptr(`UBR`), nil, &valType, nil, &bufLen)
+	if err == nil {
+		regBuf := make([]byte, 4)
+		err = windows.RegQueryValueEx(h, windows.StringToUTF16Ptr(`UBR`), nil, &valType, (*byte)(unsafe.Pointer(&regBuf[0])), &bufLen)
+		copy((*[4]byte)(unsafe.Pointer(&UBR))[:], regBuf)
+	}
+
+	// Get DisplayVersion(ex: 23H2) as platformVersion
+	err = windows.RegQueryValueEx(h, windows.StringToUTF16Ptr(`DisplayVersion`), nil, &valType, nil, &bufLen)
+	if err == nil {
+		regBuf := make([]uint16, bufLen/2+1)
+		err = windows.RegQueryValueEx(h, windows.StringToUTF16Ptr(`DisplayVersion`), nil, &valType, (*byte)(unsafe.Pointer(&regBuf[0])), &bufLen)
+		displayVersion = windows.UTF16ToString(regBuf[:])
+	}
+
 	// PlatformFamily
 	switch osInfo.wProductType {
 	case 1:
@@ -222,42 +226,56 @@ func PlatformInformationWithContext(ctx context.Context) (platform string, famil
 	}
 
 	// Platform Version
-	version = fmt.Sprintf("%d.%d.%d Build %d", osInfo.dwMajorVersion, osInfo.dwMinorVersion, osInfo.dwBuildNumber, osInfo.dwBuildNumber)
+	version = fmt.Sprintf("%d.%d.%d.%d Build %d.%d",
+		osInfo.dwMajorVersion, osInfo.dwMinorVersion, osInfo.dwBuildNumber, UBR,
+		osInfo.dwBuildNumber, UBR)
 
-	return platform, family, version, nil
-}
-
-func Users() ([]UserStat, error) {
-	return UsersWithContext(context.Background())
+	return platform, family, version, displayVersion, nil
 }
 
 func UsersWithContext(ctx context.Context) ([]UserStat, error) {
 	var ret []UserStat
 
-	return ret, nil
-}
-
-func SensorsTemperatures() ([]TemperatureStat, error) {
-	return SensorsTemperaturesWithContext(context.Background())
-}
-
-func SensorsTemperaturesWithContext(ctx context.Context) ([]TemperatureStat, error) {
-	return []TemperatureStat{}, common.ErrNotImplementedError
-}
-
-func Virtualization() (string, string, error) {
-	return VirtualizationWithContext(context.Background())
+	return ret, common.ErrNotImplementedError
 }
 
 func VirtualizationWithContext(ctx context.Context) (string, string, error) {
 	return "", "", common.ErrNotImplementedError
 }
 
-func KernelVersion() (string, error) {
-	return KernelVersionWithContext(context.Background())
-}
-
 func KernelVersionWithContext(ctx context.Context) (string, error) {
-	_, _, version, err := PlatformInformation()
+	_, _, version, _, err := platformInformation(ctx)
 	return version, err
 }
+
+func KernelArch() (string, error) {
+	var systemInfo systemInfo
+	procGetNativeSystemInfo.Call(uintptr(unsafe.Pointer(&systemInfo)))
+
+	const (
+		PROCESSOR_ARCHITECTURE_INTEL = 0
+		PROCESSOR_ARCHITECTURE_ARM   = 5
+		PROCESSOR_ARCHITECTURE_ARM64 = 12
+		PROCESSOR_ARCHITECTURE_IA64  = 6
+		PROCESSOR_ARCHITECTURE_AMD64 = 9
+	)
+	switch systemInfo.wProcessorArchitecture {
+	case PROCESSOR_ARCHITECTURE_INTEL:
+		if systemInfo.wProcessorLevel < 3 {
+			return "i386", nil
+		}
+		if systemInfo.wProcessorLevel > 6 {
+			return "i686", nil
+		}
+		return fmt.Sprintf("i%d86", systemInfo.wProcessorLevel), nil
+	case PROCESSOR_ARCHITECTURE_ARM:
+		return "arm", nil
+	case PROCESSOR_ARCHITECTURE_ARM64:
+		return "aarch64", nil
+	case PROCESSOR_ARCHITECTURE_IA64:
+		return "ia64", nil
+	case PROCESSOR_ARCHITECTURE_AMD64:
+		return "x86_64", nil
+	}
+	return "", nil
+}
