@@ -1,3 +1,4 @@
+// SPDX-License-Identifier: BSD-3-Clause
 package process
 
 import (
@@ -21,7 +22,7 @@ import (
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 
-	"github.com/shirou/gopsutil/v3/internal/common"
+	"github.com/shirou/gopsutil/v4/internal/common"
 )
 
 var mu sync.Mutex
@@ -38,7 +39,7 @@ func testGetProcess() Process {
 	return *ret
 }
 
-func Test_Pids(t *testing.T) {
+func TestPids(t *testing.T) {
 	ret, err := Pids()
 	skipIfNotImplementedErr(t, err)
 	if err != nil {
@@ -49,7 +50,7 @@ func Test_Pids(t *testing.T) {
 	}
 }
 
-func Test_Pid_exists(t *testing.T) {
+func TestPid_exists(t *testing.T) {
 	checkPid := os.Getpid()
 
 	ret, err := PidExists(int32(checkPid))
@@ -63,7 +64,7 @@ func Test_Pid_exists(t *testing.T) {
 	}
 }
 
-func Test_NewProcess(t *testing.T) {
+func TestNewProcess(t *testing.T) {
 	checkPid := os.Getpid()
 
 	ret, err := NewProcess(int32(checkPid))
@@ -79,7 +80,7 @@ func Test_NewProcess(t *testing.T) {
 	}
 }
 
-func Test_Process_memory_maps(t *testing.T) {
+func TestMemoryMaps(t *testing.T) {
 	checkPid := os.Getpid()
 
 	ret, err := NewProcess(int32(checkPid))
@@ -115,7 +116,7 @@ func Test_Process_memory_maps(t *testing.T) {
 	}
 }
 
-func Test_Process_MemoryInfo(t *testing.T) {
+func TestMemoryInfo(t *testing.T) {
 	p := testGetProcess()
 
 	v, err := p.MemoryInfo()
@@ -129,7 +130,7 @@ func Test_Process_MemoryInfo(t *testing.T) {
 	}
 }
 
-func Test_Process_CmdLine(t *testing.T) {
+func TestCmdLine(t *testing.T) {
 	p := testGetProcess()
 
 	v, err := p.Cmdline()
@@ -142,7 +143,7 @@ func Test_Process_CmdLine(t *testing.T) {
 	}
 }
 
-func Test_Process_CmdLineSlice(t *testing.T) {
+func TestCmdLineSlice(t *testing.T) {
 	p := testGetProcess()
 
 	v, err := p.CmdlineSlice()
@@ -155,7 +156,7 @@ func Test_Process_CmdLineSlice(t *testing.T) {
 	}
 }
 
-func Test_Process_Ppid(t *testing.T) {
+func TestPpid(t *testing.T) {
 	p := testGetProcess()
 
 	v, err := p.Ppid()
@@ -172,7 +173,7 @@ func Test_Process_Ppid(t *testing.T) {
 	}
 }
 
-func Test_Process_Status(t *testing.T) {
+func TestStatus(t *testing.T) {
 	p := testGetProcess()
 
 	v, err := p.Status()
@@ -188,7 +189,7 @@ func Test_Process_Status(t *testing.T) {
 	}
 }
 
-func Test_Process_Terminal(t *testing.T) {
+func TestTerminal(t *testing.T) {
 	p := testGetProcess()
 
 	_, err := p.Terminal()
@@ -198,7 +199,7 @@ func Test_Process_Terminal(t *testing.T) {
 	}
 }
 
-func Test_Process_IOCounters(t *testing.T) {
+func TestIOCounters(t *testing.T) {
 	p := testGetProcess()
 
 	v, err := p.IOCounters()
@@ -213,7 +214,7 @@ func Test_Process_IOCounters(t *testing.T) {
 	}
 }
 
-func Test_Process_NumCtx(t *testing.T) {
+func TestNumCtx(t *testing.T) {
 	p := testGetProcess()
 
 	_, err := p.NumCtxSwitches()
@@ -224,7 +225,7 @@ func Test_Process_NumCtx(t *testing.T) {
 	}
 }
 
-func Test_Process_Nice(t *testing.T) {
+func TestNice(t *testing.T) {
 	p := testGetProcess()
 
 	// https://github.com/shirou/gopsutil/issues/1532
@@ -242,7 +243,7 @@ func Test_Process_Nice(t *testing.T) {
 	}
 }
 
-func Test_Process_Groups(t *testing.T) {
+func TestGroups(t *testing.T) {
 	p := testGetProcess()
 
 	v, err := p.Groups()
@@ -258,7 +259,7 @@ func Test_Process_Groups(t *testing.T) {
 	}
 }
 
-func Test_Process_NumThread(t *testing.T) {
+func TestNumThread(t *testing.T) {
 	p := testGetProcess()
 
 	n, err := p.NumThreads()
@@ -271,7 +272,7 @@ func Test_Process_NumThread(t *testing.T) {
 	}
 }
 
-func Test_Process_Threads(t *testing.T) {
+func TestThreads(t *testing.T) {
 	p := testGetProcess()
 
 	n, err := p.NumThreads()
@@ -293,7 +294,7 @@ func Test_Process_Threads(t *testing.T) {
 	}
 }
 
-func Test_Process_Name(t *testing.T) {
+func TestName(t *testing.T) {
 	p := testGetProcess()
 
 	n, err := p.Name()
@@ -306,7 +307,8 @@ func Test_Process_Name(t *testing.T) {
 	}
 }
 
-func Test_Process_Long_Name_With_Spaces(t *testing.T) {
+// #nosec G204
+func TestLong_Name_With_Spaces(t *testing.T) {
 	tmpdir, err := os.MkdirTemp("", "")
 	if err != nil {
 		t.Fatalf("unable to create temp dir %v", err)
@@ -352,7 +354,8 @@ func Test_Process_Long_Name_With_Spaces(t *testing.T) {
 	cmd.Process.Kill()
 }
 
-func Test_Process_Long_Name(t *testing.T) {
+// #nosec G204
+func TestLong_Name(t *testing.T) {
 	tmpdir, err := os.MkdirTemp("", "")
 	if err != nil {
 		t.Fatalf("unable to create temp dir %v", err)
@@ -398,7 +401,7 @@ func Test_Process_Long_Name(t *testing.T) {
 	cmd.Process.Kill()
 }
 
-func Test_Process_Name_Against_Python(t *testing.T) {
+func TestName_Against_Python(t *testing.T) {
 	if runtime.GOOS == "windows" {
 		t.Skip("only applies to posix")
 	}
@@ -454,7 +457,7 @@ func Test_Process_Name_Against_Python(t *testing.T) {
 	}
 }
 
-func Test_Process_Exe(t *testing.T) {
+func TestExe(t *testing.T) {
 	p := testGetProcess()
 
 	n, err := p.Exe()
@@ -467,7 +470,7 @@ func Test_Process_Exe(t *testing.T) {
 	}
 }
 
-func Test_Process_CpuPercent(t *testing.T) {
+func TestCpuPercent(t *testing.T) {
 	p := testGetProcess()
 	_, err := p.Percent(0)
 	skipIfNotImplementedErr(t, err)
@@ -488,7 +491,7 @@ func Test_Process_CpuPercent(t *testing.T) {
 	}
 }
 
-func Test_Process_CpuPercentLoop(t *testing.T) {
+func TestCpuPercentLoop(t *testing.T) {
 	p := testGetProcess()
 	numcpu := runtime.NumCPU()
 
@@ -506,7 +509,7 @@ func Test_Process_CpuPercentLoop(t *testing.T) {
 	}
 }
 
-func Test_Process_CreateTime(t *testing.T) {
+func TestCreateTime(t *testing.T) {
 	if os.Getenv("CI") == "true" {
 		t.Skip("Skip CI")
 	}
@@ -531,7 +534,7 @@ func Test_Process_CreateTime(t *testing.T) {
 	}
 }
 
-func Test_Parent(t *testing.T) {
+func TestParent(t *testing.T) {
 	p := testGetProcess()
 
 	c, err := p.Parent()
@@ -547,7 +550,7 @@ func Test_Parent(t *testing.T) {
 	}
 }
 
-func Test_Connections(t *testing.T) {
+func TestConnections(t *testing.T) {
 	p := testGetProcess()
 
 	addr, err := net.ResolveTCPAddr("tcp", "localhost:0") // dynamically get a random open port from OS
@@ -630,7 +633,7 @@ func Test_Connections(t *testing.T) {
 	}
 }
 
-func Test_Children(t *testing.T) {
+func TestChildren(t *testing.T) {
 	p := testGetProcess()
 
 	var cmd *exec.Cmd
@@ -662,7 +665,7 @@ func Test_Children(t *testing.T) {
 	}
 }
 
-func Test_Username(t *testing.T) {
+func TestUsername(t *testing.T) {
 	myPid := os.Getpid()
 	currentUser, _ := user.Current()
 	myUsername := currentUser.Username
@@ -675,7 +678,7 @@ func Test_Username(t *testing.T) {
 	t.Log(pidUsername)
 }
 
-func Test_CPUTimes(t *testing.T) {
+func TestCPUTimes(t *testing.T) {
 	pid := os.Getpid()
 	process, err := NewProcess(int32(pid))
 	skipIfNotImplementedErr(t, err)
@@ -707,7 +710,7 @@ func Test_CPUTimes(t *testing.T) {
 	assert.True(t, measuredElapsed < float64(spinSeconds)*5, message)
 }
 
-func Test_OpenFiles(t *testing.T) {
+func TestOpenFiles(t *testing.T) {
 	fp, err := os.Open("process_test.go")
 	assert.Nil(t, err)
 	defer func() {
@@ -730,7 +733,7 @@ func Test_OpenFiles(t *testing.T) {
 	}
 }
 
-func Test_Kill(t *testing.T) {
+func TestKill(t *testing.T) {
 	var cmd *exec.Cmd
 	if runtime.GOOS == "windows" {
 		cmd = exec.Command("ping", "localhost", "-n", "4")
@@ -748,7 +751,7 @@ func Test_Kill(t *testing.T) {
 	cmd.Wait()
 }
 
-func Test_IsRunning(t *testing.T) {
+func TestIsRunning(t *testing.T) {
 	var cmd *exec.Cmd
 	if runtime.GOOS == "windows" {
 		cmd = exec.Command("ping", "localhost", "-n", "2")
@@ -778,7 +781,8 @@ func Test_IsRunning(t *testing.T) {
 	}
 }
 
-func Test_Process_Environ(t *testing.T) {
+// #nosec G204
+func TestEnviron(t *testing.T) {
 	tmpdir, err := os.MkdirTemp("", "")
 	if err != nil {
 		t.Fatalf("unable to create temp dir %v", err)
@@ -832,7 +836,7 @@ func Test_Process_Environ(t *testing.T) {
 	}
 }
 
-func Test_Process_Cwd(t *testing.T) {
+func TestCwd(t *testing.T) {
 	myPid := os.Getpid()
 	currentWorkingDirectory, _ := os.Getwd()
 
